/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer;

import javax.swing.AbstractAction;
import javax.swing.Icon;

/**
 * <p>
 * Utility wrapper for Abstract action to indicate an action on a layer object
 * </p>
 *<p>
 * Layer object actions should extend this class and make themselves known through the
 * ServiceProvider annotation like this:</p>
 * <p>
 * <code> &#64;ServiceProvider(service=GeographicalAction.class)</code>
 * </p>
 * <p>
 * Registered actions will be considered global layer object actions and will be added
 * to all layer object nodes. For actions for specific layer objects,  implement the {@link LayerObject#getActions() } method.
 * </p>
 * @author Timon Veenstra
 */
public abstract class GeographicalAction extends AbstractAction {

    /**
     * Create a GeographicalAction with a name and an icon
     * @param name The name of this GeographicalAction
     * @param icon The icon of this GeographicalAction
     */
    public GeographicalAction(String name, Icon icon) {
        super(name,icon);
    }

    /**
     * Create a GeographicalAction with a name
     * @param name The name of this GeographicalAction
     */
    public GeographicalAction(String name) {
        super(name);
    }

    /**
     * Create a nameless GeographicalAction
     */
    public GeographicalAction() {
        super();
    }

    

}
